==> nextcloud-app-mail-0.15.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fr.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Inbox" : "Boîte de réception",
    "Sent" : "Envoyés",
    "Drafts" : "Brouillons",
    "Archive" : "Archives",
    "Trash" : "Corbeille",
    "Junk" : "Indésirables",
    "All" : "Tous",
    "Favorites" : "Favoris",
    "Auto detect failed. Please use manual mode." : "L'auto-détection a échoué. Veuillez utiliser le mode manuel.",
    "Updating account failed: " : "La mise à jour du compte a échoué : ",
    "Creating account failed: " : "La création du compte a échoué : ",
    "Delete permanently" : "Supprimer définitivement",
    "IMAP web client" : "Client web IMAP",
    "Easy to use email client which connects to your mail server via IMAP and SMTP." : "Client de messagerie facile à utiliser qui se connecte à votre serveur de messagerie via IMAP et SMTP.",
    "Auto" : "Auto",
    "Name" : "Nom",
    "Mail Address" : "Adresse mail",
    "Password" : "Mot de passe",
    "Manual" : "Manuel",
    "IMAP Settings" : "Paramètres IMAP",
    "IMAP Host" : "Hôte IMAP",
    "IMAP Security" : "Sécurité IMAP",
    "None" : "Aucun",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Utilisateur IMAP",
    "IMAP Password" : "Mot de passe IMAP",
    "SMTP Settings" : "Paramètres SMTP",
    "SMTP Host" : "Hôte SMTP",
    "SMTP Security" : "Sécurité SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Save" : "Enregistrer",
    "Connect" : "Connecter",
    "Add mail account" : "Ajouter un compte mail",
    "Use Gravatar and favicon avatars" : "Utiliser Gravatar et des avatars de favicon",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Vous recherchez comment protéger vos courriels ? Installez l'extension Mailvelope browser !",
    "from" : "de",
    "to" : "vers",
    "+ cc/bcc" : "+ cc/bcc",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Sujet",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Notez que le mail provient d'une adresse noreply donc\tvotre réponse ne sera sans doute pas lu.",
    "Message …" : "Message …",
    "Saving draft …" : "Sauvegarde du brouillon en cours …",
    "Draft saved" : "Brouillon sauvegardé",
    "Uploading attachments …" : "Téléversement des pièces jointes en cours …",
    "Sending …" : "Envoi…",
    "Error sending your message" : "Erreur lors de l'envoi de votre message",
    "Go back" : "Revenir en arrière",
    "Retry" : "Réessayer",
    "Message sent!" : "Message envoyé !",
    "Reply sent!" : "Réponse envoyé !",
    "Write another message" : "Écrire un autre message",
    "Send" : "Envoyer",
    "Uploading {percent}% …" : "Envoi {percent}% …",
    "Upload attachment" : "Téléverser les pièces jointes",
    "Add attachment from Files" : "Ajouter des pièces jointes depuis Fichiers",
    "Choose a file to add as attachment" : "Choisissez un fichier à joindre au message",
    "No messages in this folder" : "Aucun message dans ce dossier",
    "Draft: " : "Brouillon :",
    "Mark read" : "Marquer comme lu",
    "Mark unread" : "Marquer comme non-lu",
    "Delete" : "Supprimer",
    "Report this bug" : "Signaler ce bogue",
    "Loading messages" : "Chargement des messages",
    "Not found" : "Non trouvé",
    "Could not load your message" : "Impossible de charger votre message",
    "Import into calendar" : "Importer dans le calendrier",
    "Download attachment" : "Télécharger les pièces jointes",
    "Save to Files" : "Enregistrer dans Fichiers",
    "Choose a folder to store the attachment in" : "Choisissez le dossier dans lequel enregistrer la pièce jointe",
    "Save all to Files" : "Enregistrer tout dans les Fichiers",
    "Choose a folder to store the attachments in" : "Choisissez un dossier dans lequel enregistrer les pièces jointes",
    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
    "Show images from this\tsender" : "Voir les images de cet\texpéditeur",
    "New message" : "Nouveau message",
    "Settings" : "Paramètres",
    "Edit" : "Modifier",
    "Add folder" : "Ajouter un dossier",
    "Show all folders" : "Montrer tous les dossiers",
    "Collapse folders" : "Replier les dossiers",
    "Loading …" : "Chargement …",
    "{total} messages ({unread} unread)" : "{total} messages ({unread} non lus)",
    "Mark all as read" : "Marquer tout comme lu",
    "Mark all messages of this folder as read" : "Marquer tous les messages de ce dossier comme lus",
    "Add subfolder" : "Ajouter un sous-dossier",
    "Could not load your draft" : "Impossible de charger votre brouillon",
    "No message selected" : "Aucun message sélectionné",
    "Signature" : "Signature",
    "A signature will be added to the text of new and response messages." : "Une signature sera ajoutée sur les nouveaux messages et les réponses.",
    "Account Settings" : "Paramètres du compte",
    "Mail server" : "Serveur de messagerie",
    "Speed up your Mail experience with these quick shortcuts." : "Accélérez votre expérience Mail avec ces raccourcis rapides.",
    "Compose new message" : "Rédigez un nouveau message",
    "Newer message" : "Message plus récent",
    "Older message" : "Message plus ancien",
    "Toggle star" : "Épingler / Désépingler",
    "Toggle unread" : "Basculer en lu/non lu",
    "Search" : "Rechercher",
    "Refresh" : "Rafraîchir",
    "Connect your mail account" : "Connecter votre compte mail",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nouveau message\nde {from}","%n nouveaux messages\nde {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "All inboxes" : "Toutes les boîtes",
    "Could not load {tag}{name}{endtag}" : "Impossible de charger {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Il y a eu un problème de chargement {tag}{name}{endtag}",
    "Could not load the desired message" : "Impossible de charger le message souhaité",
    "Could not load the message" : "Impossible de charger le message",
    "Error loading message" : "Erreur lors du chargement du message",
    "Forwarding to %s" : "Faire suivre à %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliquer ici si vous n'êtes pas automatiquement redirigé dans les prochaines secondes.",
    "Redirect" : "Redirection",
    "The link leads to %s" : "Le lien dirige vers %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si vous ne désirez pas visiter cette page, vous pouvez retourner aux <a href=\"%s\">Mails</a>.",
    "Continue to %s" : "Continuer vers %s"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-app-mail-0.17.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/mail/l10n/fr.js <==
OC.L10N.register(
    "mail",
    {
    "Mail" : "Mail",
    "Inbox" : "Boîte de réception",
    "Sent" : "Envoyés",
    "Drafts" : "Brouillons",
    "Archive" : "Archives",
    "Trash" : "Corbeille",
    "Junk" : "Indésirables",
    "All" : "Tous",
    "Favorites" : "Favoris",
    "Auto detect failed. Please use manual mode." : "L'auto-détection a échoué. Veuillez utiliser le mode manuel.",
    "Updating account failed: " : "La mise à jour du compte a échoué : ",
    "Creating account failed: " : "La création du compte a échoué : ",
    "Delete permanently" : "Supprimer définitivement",
    "💌 A mail app for Nextcloud" : "Une application de courriels pour Nextcloud",
    "Auto" : "Auto",
    "Name" : "Nom",
    "Mail Address" : "Adresse mail",
    "Password" : "Mot de passe",
    "Manual" : "Manuel",
    "IMAP Settings" : "Paramètres IMAP",
    "IMAP Host" : "Hôte IMAP",
    "IMAP Security" : "Sécurité IMAP",
    "None" : "Aucun",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "Port IMAP",
    "IMAP User" : "Utilisateur IMAP",
    "IMAP Password" : "Mot de passe IMAP",
    "SMTP Settings" : "Paramètres SMTP",
    "SMTP Host" : "Hôte SMTP",
    "SMTP Security" : "Sécurité SMTP",
    "SMTP Port" : "Port SMTP",
    "SMTP User" : "Utilisateur SMTP",
    "SMTP Password" : "Mot de passe SMTP",
    "Save" : "Enregistrer",
    "Connect" : "Connecter",
    "Add mail account" : "Ajouter un compte mail",
    "Use Gravatar and favicon avatars" : "Utiliser Gravatar et des avatars de favicon",
    "Keyboard shortcuts" : "Raccourcis clavier",
    "Looking for a way to encrypt your emails? Install the Mailvelope browser extension!" : "Vous recherchez comment protéger vos courriels ? Installez l'extension Mailvelope browser !",
    "from" : "de",
    "to" : "vers",
    "+ cc/bcc" : "+ cc/bcc",
    "cc" : "cc",
    "bcc" : "bcc",
    "Subject" : "Sujet",
    "This mail does not have a subject yet." : "L’objet de ce courriel n'est pas encore renseigné.",
    "Note that the mail came from a noreply address so\tyour reply will probably not be read." : "Notez que le mail provient d'une adresse noreply donc\tvotre réponse ne sera sans doute pas lu.",
    "Message …" : "Message …",
    "Saving draft …" : "Sauvegarde du brouillon en cours …",
    "Draft saved" : "Brouillon sauvegardé",
    "Uploading attachments …" : "Téléversement des pièces jointes en cours …",
    "Sending …" : "Envoi…",
    "Error sending your message" : "Erreur lors de l'envoi de votre message",
    "Go back" : "Revenir en arrière",
    "Retry" : "Réessayer",
    "Message sent!" : "Message envoyé !",
    "Reply sent!" : "Réponse envoyé !",
    "Write another message" : "Écrire un autre message",
    "Send" : "Envoyer",
    "Uploading {percent}% …" : "Envoi {percent}% …",
    "Upload attachment" : "Téléverser les pièces jointes",
    "Add attachment from Files" : "Ajouter des pièces jointes depuis Fichiers",
    "Choose a file to add as attachment" : "Choisissez un fichier à joindre au message",
    "No messages in this folder" : "Aucun message dans ce dossier",
    "Draft: " : "Brouillon :",
    "Mark read" : "Marquer comme lu",
    "Mark unread" : "Marquer comme non-lu",
    "Delete" : "Supprimer",
    "Report this bug" : "Signaler ce bogue",
    "Loading messages" : "Chargement des messages",
    "Not found" : "Non trouvé",
    "Forward" : "Faire suivre",
    "Could not load your message" : "Impossible de charger votre message",
    "Import into calendar" : "Importer dans le calendrier",
    "Download attachment" : "Télécharger les pièces jointes",
    "Save to Files" : "Enregistrer dans Fichiers",
    "Choose a folder to store the attachment in" : "Choisissez le dossier dans lequel enregistrer la pièce jointe",
    "Save all to Files" : "Enregistrer tout dans les Fichiers",
    "Choose a folder to store the attachments in" : "Choisissez un dossier dans lequel enregistrer les pièces jointes",
    "The images have been blocked to protect your privacy." : "Les images ont été bloquées pour protéger votre vie privée.",
    "Show images from this\tsender" : "Voir les images de cet\texpéditeur",
    "New message" : "Nouveau message",
    "Settings" : "Paramètres",
    "Edit" : "Modifier",
    "Add folder" : "Ajouter un dossier",
    "Show all folders" : "Montrer tous les dossiers",
    "Collapse folders" : "Replier les dossiers",
    "Loading …" : "Chargement …",
    "{total} messages ({unread} unread)" : "{total} messages ({unread} non lus)",
    "Mark all as read" : "Marquer tout comme lu",
    "Mark all messages of this folder as read" : "Marquer tous les messages de ce dossier comme lus",
    "Add subfolder" : "Ajouter un sous-dossier",
    "Could not load your draft" : "Impossible de charger votre brouillon",
    "No message selected" : "Aucun message sélectionné",
    "Signature" : "Signature",
    "A signature will be added to the text of new and response messages." : "Une signature sera ajoutée sur les nouveaux messages et les réponses.",
    "Account Settings" : "Paramètres du compte",
    "Mail server" : "Serveur de messagerie",
    "Speed up your Mail experience with these quick shortcuts." : "Accélérez votre expérience Mail avec ces raccourcis rapides.",
    "Compose new message" : "Rédigez un nouveau message",
    "Newer message" : "Message plus récent",
    "Older message" : "Message plus ancien",
    "Toggle star" : "Épingler / Désépingler",
    "Toggle unread" : "Basculer en lu/non lu",
    "Search" : "Rechercher",
    "Refresh" : "Rafraîchir",
    "Connect your mail account" : "Connecter votre compte mail",
    "{from}\n{subject}" : "{from}\n{subject}",
    "_%n new message \nfrom {from}_::_%n new messages \nfrom {from}_" : ["%n nouveau message\nde {from}","%n nouveaux messages\nde {from}"],
    "Nextcloud Mail" : "Nextcloud Mail",
    "All inboxes" : "Toutes les boîtes",
    "Could not load {tag}{name}{endtag}" : "Impossible de charger {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Il y a eu un problème de chargement {tag}{name}{endtag}",
    "Could not load the desired message" : "Impossible de charger le message souhaité",
    "Could not load the message" : "Impossible de charger le message",
    "Error loading message" : "Erreur lors du chargement du message",
    "Forwarding to %s" : "Faire suivre à %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Cliquer ici si vous n'êtes pas automatiquement redirigé dans les prochaines secondes.",
    "Redirect" : "Redirection",
    "The link leads to %s" : "Le lien dirige vers %s",
    "If you don’t want to visit that page, you can return to <a href=\"%s\">Mail</a>." : "Si vous ne désirez pas visiter cette page, vous pouvez retourner aux <a href=\"%s\">Mails</a>.",
    "Continue to %s" : "Continuer vers %s"
},
"nplurals=2; plural=(n > 1);");
